@@ -1,15 +1,3 @@
-as_iterator <- function(x) {
-  i <- 0
-  n <- length(x)
-  function() {
-    i <<- i + 1
-    
-    if (i > n)
-      stop_iteration_error()
-    
-    x[[i]]
-  }
-}
 
 #' @export
 length.utils_sampler <- function(x) {
@@ -40,14 +28,7 @@ SequentialSampler <- R6::R6Class(
     .iter = function() {
       i <- 0
       n <- length(self$data_source)
-      function() {
-        i <<- i + 1
-        
-        if (i > n)
-          stop_iteration_error()
-        
-        i
-      }
+      coro::as_iterator(seq_len(n))
     },
     .length = function() {
       length(self$data_source)
@@ -68,6 +49,7 @@ RandomSampler <- R6::R6Class(
     },
     .iter = function() {
       n <- length(self$data_source)
+      
       if (self$replacement) {
         rand_tensor <- torch_randint(low = 1, high = n + 1, size = self$num_samples,
                                      dtype = torch_long(), generator = self$generator)
@@ -102,34 +84,21 @@ BatchSampler <- R6::R6Class(
       self$drop_last <- drop_last
     },
     .iter = function() {
-      s <- self$sampler$.iter()
-      function() {
+      coro::generator(function() {
         batch <- list()
-        for (i in seq_len(self$batch_size)) {
-          
-          er <- FALSE
-          
-          tryCatch(
-            obs <- s(),
-            stop_iteration_error = function(err) {
-              er <<- TRUE
-            }
-          )
-          
-          if (er)
-            break
-          
-          batch <- append(batch, obs)
+        
+        for(idx in self$sampler) {
+          batch[[length(batch) + 1]] <- idx
+          if (length(batch) == self$batch_size) {
+            yield(batch)
+            batch <- list()
+          }
         }
         
-        if (length(batch) == self$batch_size)
-          return(batch)
-        
         if (length(batch) > 0 && !self$drop_last)
-          return(batch)
-          
-        stop_iteration_error()
-      }
+          yield(batch)
+        
+      })()
     },
     .length = function() {
       if (self$drop_last) {
@@ -139,4 +108,12 @@ BatchSampler <- R6::R6Class(
       }
     }
   )
-)
\ No newline at end of file
+)
+
+#' @export
+as_iterator.utils_sampler <- function(x) {
+  it <- x$.iter()
+  function() {
+    it()
+  }
+}
\ No newline at end of file
