@@ -71,6 +71,11 @@ test_that("Integer tensors", {
   
   expect_equal(as.integer64(z), x)
   
+  x <- torch_tensor(.Machine$integer.max)
+  expect_equal(as.integer(x), .Machine$integer.max)
+  expect_warning(as_array(2L*x))
+  expect_warning(as.integer(2L*x))
+  
 })
 
 test_that("Logical tensors", {
@@ -162,22 +167,22 @@ test_that("as.matrix", {
   
   x <- torch_randn(2,2)
   r <- as.matrix(x)
-  expect_equal(class(r), c("matrix", "array"))
+  expect_true("matrix" %in% class(r))
   expect_equal(dim(r), c(2,2))
   
   x <- torch_randn(2,2,2)
   r <- as.matrix(x)
-  expect_equal(class(r), c("matrix", "array"))
+  expect_true("matrix" %in% class(r))
   expect_equal(dim(r), c(8,1))
   
 })
 
 test_that("print tensor is truncated", {
-  
-  expect_known_value(torch_arange(0, 100), file = "assets/print1")
-  expect_known_value(torch_arange(0, 25), file = "assets/print2")
-  expect_known_value(print(torch_arange(0, 100), n = 50), file = "assets/print3")
-  expect_known_value(print(torch_arange(0, 100), n = -1), file = "assets/print4")
+  local_edition(3)
+  expect_snapshot_output(torch_arange(0, 100))
+  expect_snapshot_output(torch_arange(0, 25))
+  expect_snapshot_output(print(torch_arange(0, 100), n = 50))
+  expect_snapshot_output(print(torch_arange(0, 100), n = -1))
   
 })
 
@@ -263,4 +268,56 @@ test_that("max and min", {
     class = "value_error"
   )
   
-}) 
+})
+
+test_that("element_size works", {
+  x <- torch_tensor(1, dtype = torch_int8())
+  result <- x$element_size()
+  expect_equal(result, 1L)
+  types <- list(
+    torch_float32(),
+    torch_float(),
+    torch_float64(),
+    torch_double(),
+    torch_float16(),
+    torch_half(),
+    torch_uint8(),
+    torch_int8(),
+    torch_int16(),
+    torch_short(),
+    torch_int32(),
+    torch_int(),
+    torch_int64(),
+    torch_long(),
+    torch_bool(),
+    torch_quint8(),
+    torch_qint8(),
+    torch_qint32()
+  )
+  for (type in types) {
+    
+    if (type == torch_quint8() || type == torch_qint8() || type == torch_qint32()) {
+      x <- torch_tensor(1, dtype = torch_float())
+      x <- torch_quantize_per_tensor(x, scale = 0.1, zero_point = 10, dtype = type)
+    } else {
+      x <- torch_tensor(1, dtype = type)  
+    }
+  
+    result <- x$element_size()
+    expect_true(is.integer(result))
+    expect_true(result > 0L)
+    expect_true(length(result) == 1)
+  }
+})
+
+test_that("tensor$bool works", {
+  x <- torch_tensor(c(1,0,1))
+  result <- x$bool()
+  expected <- x$to(torch_bool())
+  expect_equal_to_tensor(result, expected)
+
+  expect_silent(
+    result <- x$bool(memory_format = torch_contiguous_format())
+  )
+  expect_equal_to_tensor(result, expected)
+})
